# TOPSIS

Title: *TOPSIS method for multiple-criteria decision making (MCDM)*.

Version: *1.0.1*.

Author: *Kriti Bhatnagar*.

Description: *Evaluation of alternatives based on multiple criteria using TOPSIS method.*

---

## How to install this package:


>> pip install Topsis__Kriti_102003628


### In Command Prompt


>> topsis data.csv "1,2,1,2,1" "+,+,-,-,+" output_file.csv


<br>

The output file will contain columns of input file along with two additional columns having Topsis_score and Rank